Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1117)

Unified Diff: Source/core/html/HTMLPlugInElement.h

Issue 931003002: Move and rename RenderPart to LayoutPart. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/HTMLObjectElement.cpp ('k') | Source/core/html/HTMLPlugInElement.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/HTMLPlugInElement.h
diff --git a/Source/core/html/HTMLPlugInElement.h b/Source/core/html/HTMLPlugInElement.h
index 46705236bd3406d10ece3985d1fa7487a16c24af..9cf661436e456699419208e59d9bfa6de3369eb9 100644
--- a/Source/core/html/HTMLPlugInElement.h
+++ b/Source/core/html/HTMLPlugInElement.h
@@ -34,7 +34,7 @@ namespace blink {
class HTMLImageLoader;
class PluginPlaceholder;
class RenderEmbeddedObject;
-class RenderPart;
+class LayoutPart;
class Widget;
enum PreferPlugInsForImagesOption {
@@ -58,7 +58,7 @@ public:
// Returns the plugin widget, forcing layout and post-layout tasks
// to happen synchronously (e.g. for JS bindings).
- // See also renderPartForJSBindings().
+ // See also layoutPartForJSBindings().
Widget* pluginWidgetForJSBindings();
SharedPersistent<v8::Object>* pluginWrapper();
@@ -93,9 +93,9 @@ protected:
virtual bool hasFallbackContent() const;
virtual bool useFallbackContent() const;
// Create or update the RenderPart and return it, triggering layout if
// necessary.
- virtual RenderPart* renderPartForJSBindings() const;
+ virtual LayoutPart* layoutPartForJSBindings() const;
bool isImageType();
bool shouldPreferPlugInsForImages() const { return m_shouldPreferPlugInsForImages; }
@@ -137,9 +137,9 @@ private:
virtual bool hasCustomFocusLogic() const override;
virtual bool isPluginElement() const override final;
// Return any existing RenderPart without triggering relayout, or 0 if it
// doesn't yet exist.
- virtual RenderPart* existingRenderPart() const = 0;
+ virtual LayoutPart* existingLayoutPart() const = 0;
virtual void updateWidgetInternal() = 0;
bool loadPlugin(const KURL&, const String& mimeType, const Vector<String>& paramNames, const Vector<String>& paramValues, bool useFallback, bool requireRenderer);
« no previous file with comments | « Source/core/html/HTMLObjectElement.cpp ('k') | Source/core/html/HTMLPlugInElement.cpp » ('j') | no next file with comments »
@@ -93,9 +93,9 @@ protected:
virtual bool hasFallbackContent() const;
virtual bool useFallbackContent() const;
- // Create or update the RenderPart and return it, triggering layout if
+ // Create or update the LayoutPart and return it, triggering layout if
// necessary.
@@ -137,9 +137,9 @@ private:
virtual bool hasCustomFocusLogic() const override;
virtual bool isPluginElement() const override final;
- // Return any existing RenderPart without triggering relayout, or 0 if it
+ // Return any existing LayoutPart without triggering relayout, or 0 if it
// doesn't yet exist.

Powered by Google App Engine
This is Rietveld 408576698